@@ -30,6 +30,8 @@
 #include <QDBusConnection>
 #include <QDBusConnectionInterface>
 
+#include <boost/scoped_ptr.hpp>
+
 using namespace Akonadi;
 
 ItemRetrievalManager* ItemRetrievalManager::sInstance = 0;
@@ -53,9 +55,6 @@ ItemRetrievalManager::ItemRetrievalManager( QObject *parent ) :
   connect( mDBusConnection.interface(), SIGNAL(serviceOwnerChanged(QString,QString,QString)),
            this, SLOT(serviceOwnerChanged(QString,QString,QString)) );
   connect( this, SIGNAL(requestAdded()), this, SLOT(processRequest()), Qt::QueuedConnection );
-  connect( this, SIGNAL(syncCollection(QString,qint64)), this, SLOT(triggerCollectionSync(QString,qint64)), Qt::QueuedConnection );
-  connect( this, SIGNAL( syncCollectionTree( const QString& ) ),
-           this, SLOT( triggerCollectionTreeSync( const QString& ) ), Qt::QueuedConnection );
 }
 
 ItemRetrievalManager::~ItemRetrievalManager()
@@ -89,9 +88,7 @@ OrgFreedesktopAkonadiResourceInterface* ItemRetrievalManager::resourceInterface(
   if ( id.isEmpty() )
     return 0;
 
-  OrgFreedesktopAkonadiResourceInterface *iface = 0;
-  if ( mResourceInterfaces.contains( id ) )
-    iface = mResourceInterfaces.value( id );
+  OrgFreedesktopAkonadiResourceInterface *iface = mResourceInterfaces.value( id );
   if ( iface && iface->isValid() )
     return iface;
 
@@ -133,17 +130,19 @@ void ItemRetrievalManager::requestItemDelivery( ItemRetrievalRequest *req )
 
   mLock->lockForRead();
   forever {
-    qDebug() << "checking if request for item" << req->id << "has been processed...";
+    //qDebug() << "checking if request for item" << req->id << "has been processed...";
     if ( req->processed ) {
+      boost::scoped_ptr<ItemRetrievalRequest> reqDeleter( req );
       Q_ASSERT( !mPendingRequests[ req->resourceId ].contains( req ) );
       const QString errorMsg = req->errorMsg;
       mLock->unlock();
-      qDebug() << "request for item" << req->id << "processed, error:" << errorMsg;
-      delete req;
-      if ( errorMsg.isEmpty() )
+      if ( errorMsg.isEmpty() ) {
+        qDebug() << "request for item" << req->id << "succeeded";
         return;
-      else
+      } else {
+        qDebug() << "request for item" << req->id << req->remoteId << "failed:" << errorMsg;
         throw ItemRetrieverException( errorMsg );
+      }
     } else {
       qDebug() << "request for item" << req->id << "still pending - waiting";
       mWaitCondition->wait( mLock );
@@ -157,7 +156,7 @@ void ItemRetrievalManager::requestItemDelivery( ItemRetrievalRequest *req )
 // called within the retrieval thread
 void ItemRetrievalManager::processRequest()
 {
-  QList<QPair<ItemRetrievalJob*, QString> > newJobs;
+  QVector<QPair<ItemRetrievalJob*, QString> > newJobs;
 
   mLock->lockForWrite();
   // look for idle resources
@@ -187,7 +186,7 @@ void ItemRetrievalManager::processRequest()
     return;
   }
 
-  for ( QList< QPair< ItemRetrievalJob*, QString > >::const_iterator it = newJobs.constBegin(); it != newJobs.constEnd(); ++it )
+  for ( QVector< QPair< ItemRetrievalJob*, QString > >::const_iterator it = newJobs.constBegin(); it != newJobs.constEnd(); ++it )
     (*it).first->start( resourceInterface( (*it).second ) );
 }
 
@@ -214,16 +213,6 @@ void ItemRetrievalManager::retrievalJobFinished(ItemRetrievalRequest* request, c
   emit requestAdded(); // trigger processRequest() again, in case there is more in the queues
 }
 
-void ItemRetrievalManager::requestCollectionSync( const Collection& collection )
-{
-  // if the collection is a resource collection we trigger a synchronization
-  // of the collection hierarchy as well
-  if ( collection.parentId() == 0 )
-    emit syncCollectionTree( collection.resource().name() );
-
-  emit syncCollection( collection.resource().name(), collection.id() );
-}
-
 void ItemRetrievalManager::triggerCollectionSync(const QString& resource, qint64 colId)
 {
   OrgFreedesktopAkonadiResourceInterface *interface = resourceInterface( resource );
